import type { BasicForm } from '@/types/form'
import type { ThemeStyle } from '@/types/themeStyle'
import navDark from '@/assets/svg/nav-theme-dark.svg'
import navLight from '@/assets/svg/nav-theme-light.svg'
import navH from '@/assets/svg/nav-h.svg'
import headerDark from '@/assets/svg/header-theme-dark.svg'

export const orgFormConfig = reactive<BasicForm>({
  span: 24,
  formItems: [
    {
      label: '组织名称',
      value: '',
      name: 'name',
      type: 'input',
      rules: [{ required: true, message: '请输入组织名称', trigger: 'blur' }],
      search: true
    },
    {
      label: '联系人姓名',
      value: '',
      name: 'contact',
      type: 'input'
    },
    {
      label: '联系人电话',
      value: '',
      name: 'phone',
      type: 'input',
      search: true,
      props: {
        maxlength: 11
      }
    },
    {
      label: '所属区域',
      value: '',
      name: 'area',
      type: 'select',
      options: []
    },
    {
      label: '详细地址',
      value: true,
      name: 'address',
      type: 'input'
    }
  ]
})

export const themeStyleList: ThemeStyle[] = [
  {
    name: 'nav-dark',
    img: navDark,
    bgColor: '#001529',
    textColor: '#BBB'
  },
  {
    name: 'nav-light',
    img: navLight,
    bgColor: '#fff',
    textColor: '#303133'
  },
  {
    name: 'header-dark',
    img: headerDark,
    bgColor: '#001529',
    textColor: '#BBB'
  }
]

export const themeNavList = [
  {
    name: 'left',
    img: navDark
  },
  {
    name: 'top',
    img: navH
  }
]

// logo 是否置于顶栏
export const logoInHeader = true

export const ACCESS_TOKEN = 'Authorization'
export const TOKEN_PREFIX = 'Bearer '
